@@ -1,14 +1,12 @@
 package Array::Set;
 
 our $DATE = '2016-09-15'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use Tie::IxHash;
-
 use Exporter qw(import);
 our @EXPORT_OK = qw(set_diff set_symdiff set_union set_intersect);
 
@@ -22,6 +20,7 @@ sub _doit {
         $opts = {};
     }
 
+    require Tie::IxHash;
     tie my(%res), 'Tie::IxHash';
 
     my $ic  = $opts->{ignore_case};
@@ -238,7 +237,7 @@ Array::Set - Perform set operations on arrays
 
 =head1 VERSION
 
-This document describes version 0.03 of Array::Set (from Perl distribution Array-Set), released on 2016-09-15.
+This document describes version 0.04 of Array::Set (from Perl distribution Array-Set), released on 2016-09-15.
 
 =head1 SYNOPSIS
 
